@@ -74,11 +74,11 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_autoscaling
-import aws_cdk.aws_ec2
-import aws_cdk.aws_iam
-import cdk_spot_one
-import constructs
+import aws_cdk.aws_autoscaling as _aws_cdk_aws_autoscaling_ceddda9d
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import cdk_spot_one as _cdk_spot_one_dd04be8a
+import constructs as _constructs_77d1e7e8
 
 
 @jsii.enum(jsii_type="cdk-ec2spot.BlockDurationMinutes")
@@ -113,11 +113,11 @@ class LaunchTemplateOptions:
     def __init__(
         self,
         *,
-        instance_profile: typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile] = None,
-        instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-        machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
-        spot_options: typing.Optional[typing.Union["SpotOptions", typing.Dict[str, typing.Any]]] = None,
-        user_data: typing.Optional[aws_cdk.aws_ec2.UserData] = None,
+        instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+        instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+        machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+        spot_options: typing.Optional[typing.Union["SpotOptions", typing.Dict[builtins.str, typing.Any]]] = None,
+        user_data: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData] = None,
     ) -> None:
         '''
         :param instance_profile: 
@@ -129,13 +129,13 @@ class LaunchTemplateOptions:
         if isinstance(spot_options, dict):
             spot_options = SpotOptions(**spot_options)
         if __debug__:
-            type_hints = typing.get_type_hints(LaunchTemplateOptions.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__78c5694463c7660a1bf299dd53edef0853cb5e71747d612f252bbe6751f6ab09)
             check_type(argname="argument instance_profile", value=instance_profile, expected_type=type_hints["instance_profile"])
             check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
             check_type(argname="argument machine_image", value=machine_image, expected_type=type_hints["machine_image"])
             check_type(argname="argument spot_options", value=spot_options, expected_type=type_hints["spot_options"])
             check_type(argname="argument user_data", value=user_data, expected_type=type_hints["user_data"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if instance_profile is not None:
             self._values["instance_profile"] = instance_profile
         if instance_type is not None:
@@ -148,19 +148,21 @@ class LaunchTemplateOptions:
             self._values["user_data"] = user_data
 
     @builtins.property
-    def instance_profile(self) -> typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile]:
+    def instance_profile(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile]:
         result = self._values.get("instance_profile")
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile], result)
 
     @builtins.property
-    def instance_type(self) -> typing.Optional[aws_cdk.aws_ec2.InstanceType]:
+    def instance_type(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType]:
         result = self._values.get("instance_type")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.InstanceType], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType], result)
 
     @builtins.property
-    def machine_image(self) -> typing.Optional[aws_cdk.aws_ec2.IMachineImage]:
+    def machine_image(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage]:
         result = self._values.get("machine_image")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IMachineImage], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage], result)
 
     @builtins.property
     def spot_options(self) -> typing.Optional["SpotOptions"]:
@@ -168,9 +170,9 @@ class LaunchTemplateOptions:
         return typing.cast(typing.Optional["SpotOptions"], result)
 
     @builtins.property
-    def user_data(self) -> typing.Optional[aws_cdk.aws_ec2.UserData]:
+    def user_data(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData]:
         result = self._values.get("user_data")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.UserData], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -185,17 +187,17 @@ class LaunchTemplateOptions:
 
 
 class Provider(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-ec2spot.Provider",
 ):
-    def __init__(self, scope: constructs.Construct, id: builtins.str) -> None:
+    def __init__(self, scope: _constructs_77d1e7e8.Construct, id: builtins.str) -> None:
         '''
         :param scope: -
         :param id: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Provider.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__0084407373686a8a72be599b128cde51292a4405581e5d7d1c7773a65a63a802)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [scope, id])
@@ -205,14 +207,14 @@ class Provider(
         self,
         id: builtins.str,
         *,
-        vpc: aws_cdk.aws_ec2.IVpc,
+        vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
         default_capacity_size: typing.Optional[jsii.Number] = None,
-        instance_profile: typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile] = None,
-        instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-        machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
-        spot_options: typing.Optional[typing.Union["SpotOptions", typing.Dict[str, typing.Any]]] = None,
-        user_data: typing.Optional[aws_cdk.aws_ec2.UserData] = None,
-    ) -> aws_cdk.aws_autoscaling.AutoScalingGroup:
+        instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+        instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+        machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+        spot_options: typing.Optional[typing.Union["SpotOptions", typing.Dict[builtins.str, typing.Any]]] = None,
+        user_data: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData] = None,
+    ) -> _aws_cdk_aws_autoscaling_ceddda9d.AutoScalingGroup:
         '''Create AutoScaling Group.
 
         :param id: AutoScaling Group ID.
@@ -225,7 +227,7 @@ class Provider(
         :param user_data: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Provider.create_auto_scaling_group)
+            type_hints = typing.get_type_hints(_typecheckingstub__3566640cbc802f982a0d4a96bb0b3267e1b9cf4b46247833afc110e8d1b4cdbe)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         options = AutoScalingGroupOptions(
             vpc=vpc,
@@ -237,7 +239,7 @@ class Provider(
             user_data=user_data,
         )
 
-        return typing.cast(aws_cdk.aws_autoscaling.AutoScalingGroup, jsii.invoke(self, "createAutoScalingGroup", [id, options]))
+        return typing.cast(_aws_cdk_aws_autoscaling_ceddda9d.AutoScalingGroup, jsii.invoke(self, "createAutoScalingGroup", [id, options]))
 
     @jsii.member(jsii_name="createFleet")
     def create_fleet(
@@ -247,15 +249,15 @@ class Provider(
         terminate_instances_with_expiration: typing.Optional[builtins.bool] = None,
         valid_from: typing.Optional[builtins.str] = None,
         valid_until: typing.Optional[builtins.str] = None,
-        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-        vpc: aws_cdk.aws_ec2.IVpc,
+        vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+        vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
         default_capacity_size: typing.Optional[jsii.Number] = None,
-        instance_profile: typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile] = None,
-        instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-        machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
-        spot_options: typing.Optional[typing.Union["SpotOptions", typing.Dict[str, typing.Any]]] = None,
-        user_data: typing.Optional[aws_cdk.aws_ec2.UserData] = None,
-    ) -> aws_cdk.aws_ec2.CfnSpotFleet:
+        instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+        instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+        machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+        spot_options: typing.Optional[typing.Union["SpotOptions", typing.Dict[builtins.str, typing.Any]]] = None,
+        user_data: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData] = None,
+    ) -> _aws_cdk_aws_ec2_ceddda9d.CfnSpotFleet:
         '''Create EC2 Spot Fleet.
 
         :param id: fleet id.
@@ -272,7 +274,7 @@ class Provider(
         :param user_data: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Provider.create_fleet)
+            type_hints = typing.get_type_hints(_typecheckingstub__3e928ee8d54727c94e6a91bef6df4107595145ad0f8fd6eef4fab296eeeeac06)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         options = SpotFleetOptions(
             terminate_instances_with_expiration=terminate_instances_with_expiration,
@@ -288,29 +290,29 @@ class Provider(
             user_data=user_data,
         )
 
-        return typing.cast(aws_cdk.aws_ec2.CfnSpotFleet, jsii.invoke(self, "createFleet", [id, options]))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.CfnSpotFleet, jsii.invoke(self, "createFleet", [id, options]))
 
     @jsii.member(jsii_name="createInstance")
     def create_instance(
         self,
         id: builtins.str,
         *,
-        block_device_mappings: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ec2.CfnLaunchTemplate.BlockDeviceMappingProperty, typing.Dict[str, typing.Any]]]] = None,
+        block_device_mappings: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.BlockDeviceMappingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
         additional_user_data: typing.Optional[typing.Sequence[builtins.str]] = None,
         assign_eip: typing.Optional[builtins.bool] = None,
         custom_ami_id: typing.Optional[builtins.str] = None,
-        default_instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
+        default_instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
         ebs_volume_size: typing.Optional[jsii.Number] = None,
         eip_allocation_id: typing.Optional[builtins.str] = None,
-        instance_interruption_behavior: typing.Optional[cdk_spot_one.InstanceInterruptionBehavior] = None,
-        instance_profile: typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile] = None,
-        instance_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        instance_interruption_behavior: typing.Optional[_cdk_spot_one_dd04be8a.InstanceInterruptionBehavior] = None,
+        instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+        instance_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
         key_name: typing.Optional[builtins.str] = None,
-        security_group: typing.Optional[aws_cdk.aws_ec2.SecurityGroup] = None,
+        security_group: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SecurityGroup] = None,
         target_capacity: typing.Optional[jsii.Number] = None,
-        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-    ) -> cdk_spot_one.SpotInstance:
+        vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+        vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+    ) -> _cdk_spot_one_dd04be8a.SpotInstance:
         '''
         :param id: -
         :param block_device_mappings: blockDeviceMappings for config instance. Default: - from ami config.
@@ -330,9 +332,9 @@ class Provider(
         :param vpc_subnet: VPC subnet for the spot fleet. Default: - public subnet
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Provider.create_instance)
+            type_hints = typing.get_type_hints(_typecheckingstub__b516a9f6810a4191589369f2dbbe5830ade0f075015b6226219713dcb779b5d6)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        optons = cdk_spot_one.SpotInstanceProps(
+        optons = _cdk_spot_one_dd04be8a.SpotInstanceProps(
             block_device_mappings=block_device_mappings,
             additional_user_data=additional_user_data,
             assign_eip=assign_eip,
@@ -350,32 +352,32 @@ class Provider(
             vpc_subnet=vpc_subnet,
         )
 
-        return typing.cast(cdk_spot_one.SpotInstance, jsii.invoke(self, "createInstance", [id, optons]))
+        return typing.cast(_cdk_spot_one_dd04be8a.SpotInstance, jsii.invoke(self, "createInstance", [id, optons]))
 
     @jsii.member(jsii_name="createInstanceProfile")
     def create_instance_profile(
         self,
         id: builtins.str,
-    ) -> aws_cdk.aws_iam.CfnInstanceProfile:
+    ) -> _aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile:
         '''
         :param id: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Provider.create_instance_profile)
+            type_hints = typing.get_type_hints(_typecheckingstub__d353190783597c3682594ef7c0b7cf17a9dc04d8a279f795a99a134a2827ab71)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        return typing.cast(aws_cdk.aws_iam.CfnInstanceProfile, jsii.invoke(self, "createInstanceProfile", [id]))
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile, jsii.invoke(self, "createInstanceProfile", [id]))
 
     @jsii.member(jsii_name="createLaunchTemplate")
     def create_launch_template(
         self,
         id: builtins.str,
         *,
-        instance_profile: typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile] = None,
-        instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-        machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
-        spot_options: typing.Optional[typing.Union["SpotOptions", typing.Dict[str, typing.Any]]] = None,
-        user_data: typing.Optional[aws_cdk.aws_ec2.UserData] = None,
-    ) -> aws_cdk.aws_ec2.CfnLaunchTemplate:
+        instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+        instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+        machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+        spot_options: typing.Optional[typing.Union["SpotOptions", typing.Dict[builtins.str, typing.Any]]] = None,
+        user_data: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData] = None,
+    ) -> _aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate:
         '''Create Launch Template.
 
         :param id: launch template id.
@@ -386,7 +388,7 @@ class Provider(
         :param user_data: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Provider.create_launch_template)
+            type_hints = typing.get_type_hints(_typecheckingstub__c7b657887259e7f17d85ad09bf8a9a9d615d1fafeb14ca39192a46d0cbc5f7b8)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         options = LaunchTemplateOptions(
             instance_profile=instance_profile,
@@ -396,17 +398,20 @@ class Provider(
             user_data=user_data,
         )
 
-        return typing.cast(aws_cdk.aws_ec2.CfnLaunchTemplate, jsii.invoke(self, "createLaunchTemplate", [id, options]))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate, jsii.invoke(self, "createLaunchTemplate", [id, options]))
 
     @jsii.member(jsii_name="getOrCreateVpc")
-    def get_or_create_vpc(self, scope: constructs.Construct) -> aws_cdk.aws_ec2.IVpc:
+    def get_or_create_vpc(
+        self,
+        scope: _constructs_77d1e7e8.Construct,
+    ) -> _aws_cdk_aws_ec2_ceddda9d.IVpc:
         '''
         :param scope: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Provider.get_or_create_vpc)
+            type_hints = typing.get_type_hints(_typecheckingstub__5f809737a45dc2605ea95c217b52d1b7273144171c5409566e2f3a48cbc7279d)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-        return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.invoke(self, "getOrCreateVpc", [scope]))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.IVpc, jsii.invoke(self, "getOrCreateVpc", [scope]))
 
     @builtins.property
     @jsii.member(jsii_name="amazonLinuxAmiImageId")
@@ -449,13 +454,13 @@ class SpotOptions:
         :param valid_until: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SpotOptions.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ae9508dd1b7712e4aa8613f6e6099edd85ce95aa1f65229913f8a4001839b7f8)
             check_type(argname="argument block_duration_minutes", value=block_duration_minutes, expected_type=type_hints["block_duration_minutes"])
             check_type(argname="argument instance_interruption_behavior", value=instance_interruption_behavior, expected_type=type_hints["instance_interruption_behavior"])
             check_type(argname="argument max_price", value=max_price, expected_type=type_hints["max_price"])
             check_type(argname="argument spot_instance_type", value=spot_instance_type, expected_type=type_hints["spot_instance_type"])
             check_type(argname="argument valid_until", value=valid_until, expected_type=type_hints["valid_until"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if block_duration_minutes is not None:
             self._values["block_duration_minutes"] = block_duration_minutes
         if instance_interruption_behavior is not None:
@@ -523,12 +528,12 @@ class AutoScalingGroupOptions(LaunchTemplateOptions):
     def __init__(
         self,
         *,
-        instance_profile: typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile] = None,
-        instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-        machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
-        spot_options: typing.Optional[typing.Union[SpotOptions, typing.Dict[str, typing.Any]]] = None,
-        user_data: typing.Optional[aws_cdk.aws_ec2.UserData] = None,
-        vpc: aws_cdk.aws_ec2.IVpc,
+        instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+        instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+        machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+        spot_options: typing.Optional[typing.Union[SpotOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+        user_data: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData] = None,
+        vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
         default_capacity_size: typing.Optional[jsii.Number] = None,
     ) -> None:
         '''
@@ -543,7 +548,7 @@ class AutoScalingGroupOptions(LaunchTemplateOptions):
         if isinstance(spot_options, dict):
             spot_options = SpotOptions(**spot_options)
         if __debug__:
-            type_hints = typing.get_type_hints(AutoScalingGroupOptions.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__59b1dd8d3301a15069c69deac346d143286429af8f0aa09e38100294c49388c3)
             check_type(argname="argument instance_profile", value=instance_profile, expected_type=type_hints["instance_profile"])
             check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
             check_type(argname="argument machine_image", value=machine_image, expected_type=type_hints["machine_image"])
@@ -551,7 +556,7 @@ class AutoScalingGroupOptions(LaunchTemplateOptions):
             check_type(argname="argument user_data", value=user_data, expected_type=type_hints["user_data"])
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
             check_type(argname="argument default_capacity_size", value=default_capacity_size, expected_type=type_hints["default_capacity_size"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "vpc": vpc,
         }
         if instance_profile is not None:
@@ -568,19 +573,21 @@ class AutoScalingGroupOptions(LaunchTemplateOptions):
             self._values["default_capacity_size"] = default_capacity_size
 
     @builtins.property
-    def instance_profile(self) -> typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile]:
+    def instance_profile(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile]:
         result = self._values.get("instance_profile")
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile], result)
 
     @builtins.property
-    def instance_type(self) -> typing.Optional[aws_cdk.aws_ec2.InstanceType]:
+    def instance_type(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType]:
         result = self._values.get("instance_type")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.InstanceType], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType], result)
 
     @builtins.property
-    def machine_image(self) -> typing.Optional[aws_cdk.aws_ec2.IMachineImage]:
+    def machine_image(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage]:
         result = self._values.get("machine_image")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IMachineImage], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage], result)
 
     @builtins.property
     def spot_options(self) -> typing.Optional[SpotOptions]:
@@ -588,16 +595,16 @@ class AutoScalingGroupOptions(LaunchTemplateOptions):
         return typing.cast(typing.Optional[SpotOptions], result)
 
     @builtins.property
-    def user_data(self) -> typing.Optional[aws_cdk.aws_ec2.UserData]:
+    def user_data(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData]:
         result = self._values.get("user_data")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.UserData], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData], result)
 
     @builtins.property
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
+    def vpc(self) -> _aws_cdk_aws_ec2_ceddda9d.IVpc:
         '''The vpc for the AutoScalingGroup.'''
         result = self._values.get("vpc")
         assert result is not None, "Required property 'vpc' is missing"
-        return typing.cast(aws_cdk.aws_ec2.IVpc, result)
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.IVpc, result)
 
     @builtins.property
     def default_capacity_size(self) -> typing.Optional[jsii.Number]:
@@ -641,17 +648,17 @@ class SpotFleetOptions(AutoScalingGroupOptions):
     def __init__(
         self,
         *,
-        instance_profile: typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile] = None,
-        instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-        machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
-        spot_options: typing.Optional[typing.Union[SpotOptions, typing.Dict[str, typing.Any]]] = None,
-        user_data: typing.Optional[aws_cdk.aws_ec2.UserData] = None,
-        vpc: aws_cdk.aws_ec2.IVpc,
+        instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+        instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+        machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+        spot_options: typing.Optional[typing.Union[SpotOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+        user_data: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData] = None,
+        vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
         default_capacity_size: typing.Optional[jsii.Number] = None,
         terminate_instances_with_expiration: typing.Optional[builtins.bool] = None,
         valid_from: typing.Optional[builtins.str] = None,
         valid_until: typing.Optional[builtins.str] = None,
-        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+        vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param instance_profile: 
@@ -669,9 +676,9 @@ class SpotFleetOptions(AutoScalingGroupOptions):
         if isinstance(spot_options, dict):
             spot_options = SpotOptions(**spot_options)
         if isinstance(vpc_subnet, dict):
-            vpc_subnet = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnet)
+            vpc_subnet = _aws_cdk_aws_ec2_ceddda9d.SubnetSelection(**vpc_subnet)
         if __debug__:
-            type_hints = typing.get_type_hints(SpotFleetOptions.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__0805845bdc6545defca9fbcf4d117953ddd60be3e05b25bb8c71ceb7fccd6444)
             check_type(argname="argument instance_profile", value=instance_profile, expected_type=type_hints["instance_profile"])
             check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
             check_type(argname="argument machine_image", value=machine_image, expected_type=type_hints["machine_image"])
@@ -683,7 +690,7 @@ class SpotFleetOptions(AutoScalingGroupOptions):
             check_type(argname="argument valid_from", value=valid_from, expected_type=type_hints["valid_from"])
             check_type(argname="argument valid_until", value=valid_until, expected_type=type_hints["valid_until"])
             check_type(argname="argument vpc_subnet", value=vpc_subnet, expected_type=type_hints["vpc_subnet"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "vpc": vpc,
         }
         if instance_profile is not None:
@@ -708,19 +715,21 @@ class SpotFleetOptions(AutoScalingGroupOptions):
             self._values["vpc_subnet"] = vpc_subnet
 
     @builtins.property
-    def instance_profile(self) -> typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile]:
+    def instance_profile(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile]:
         result = self._values.get("instance_profile")
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile], result)
 
     @builtins.property
-    def instance_type(self) -> typing.Optional[aws_cdk.aws_ec2.InstanceType]:
+    def instance_type(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType]:
         result = self._values.get("instance_type")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.InstanceType], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType], result)
 
     @builtins.property
-    def machine_image(self) -> typing.Optional[aws_cdk.aws_ec2.IMachineImage]:
+    def machine_image(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage]:
         result = self._values.get("machine_image")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IMachineImage], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage], result)
 
     @builtins.property
     def spot_options(self) -> typing.Optional[SpotOptions]:
@@ -728,16 +737,16 @@ class SpotFleetOptions(AutoScalingGroupOptions):
         return typing.cast(typing.Optional[SpotOptions], result)
 
     @builtins.property
-    def user_data(self) -> typing.Optional[aws_cdk.aws_ec2.UserData]:
+    def user_data(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData]:
         result = self._values.get("user_data")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.UserData], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData], result)
 
     @builtins.property
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
+    def vpc(self) -> _aws_cdk_aws_ec2_ceddda9d.IVpc:
         '''The vpc for the AutoScalingGroup.'''
         result = self._values.get("vpc")
         assert result is not None, "Required property 'vpc' is missing"
-        return typing.cast(aws_cdk.aws_ec2.IVpc, result)
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.IVpc, result)
 
     @builtins.property
     def default_capacity_size(self) -> typing.Optional[jsii.Number]:
@@ -776,13 +785,13 @@ class SpotFleetOptions(AutoScalingGroupOptions):
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def vpc_subnet(self) -> typing.Optional[aws_cdk.aws_ec2.SubnetSelection]:
+    def vpc_subnet(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection]:
         '''VPC subnet selection.
 
         :default: ec2.SubnetType.PRIVATE
         '''
         result = self._values.get("vpc_subnet")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.SubnetSelection], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -808,3 +817,140 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__78c5694463c7660a1bf299dd53edef0853cb5e71747d612f252bbe6751f6ab09(
+    *,
+    instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+    instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+    machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+    spot_options: typing.Optional[typing.Union[SpotOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    user_data: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0084407373686a8a72be599b128cde51292a4405581e5d7d1c7773a65a63a802(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3566640cbc802f982a0d4a96bb0b3267e1b9cf4b46247833afc110e8d1b4cdbe(
+    id: builtins.str,
+    *,
+    vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
+    default_capacity_size: typing.Optional[jsii.Number] = None,
+    instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+    instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+    machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+    spot_options: typing.Optional[typing.Union[SpotOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    user_data: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3e928ee8d54727c94e6a91bef6df4107595145ad0f8fd6eef4fab296eeeeac06(
+    id: builtins.str,
+    *,
+    terminate_instances_with_expiration: typing.Optional[builtins.bool] = None,
+    valid_from: typing.Optional[builtins.str] = None,
+    valid_until: typing.Optional[builtins.str] = None,
+    vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+    vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
+    default_capacity_size: typing.Optional[jsii.Number] = None,
+    instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+    instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+    machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+    spot_options: typing.Optional[typing.Union[SpotOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    user_data: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b516a9f6810a4191589369f2dbbe5830ade0f075015b6226219713dcb779b5d6(
+    id: builtins.str,
+    *,
+    block_device_mappings: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.BlockDeviceMappingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
+    additional_user_data: typing.Optional[typing.Sequence[builtins.str]] = None,
+    assign_eip: typing.Optional[builtins.bool] = None,
+    custom_ami_id: typing.Optional[builtins.str] = None,
+    default_instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+    ebs_volume_size: typing.Optional[jsii.Number] = None,
+    eip_allocation_id: typing.Optional[builtins.str] = None,
+    instance_interruption_behavior: typing.Optional[_cdk_spot_one_dd04be8a.InstanceInterruptionBehavior] = None,
+    instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+    instance_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    key_name: typing.Optional[builtins.str] = None,
+    security_group: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SecurityGroup] = None,
+    target_capacity: typing.Optional[jsii.Number] = None,
+    vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d353190783597c3682594ef7c0b7cf17a9dc04d8a279f795a99a134a2827ab71(
+    id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c7b657887259e7f17d85ad09bf8a9a9d615d1fafeb14ca39192a46d0cbc5f7b8(
+    id: builtins.str,
+    *,
+    instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+    instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+    machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+    spot_options: typing.Optional[typing.Union[SpotOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    user_data: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5f809737a45dc2605ea95c217b52d1b7273144171c5409566e2f3a48cbc7279d(
+    scope: _constructs_77d1e7e8.Construct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ae9508dd1b7712e4aa8613f6e6099edd85ce95aa1f65229913f8a4001839b7f8(
+    *,
+    block_duration_minutes: typing.Optional[BlockDurationMinutes] = None,
+    instance_interruption_behavior: typing.Optional[InstanceInterruptionBehavior] = None,
+    max_price: typing.Optional[builtins.str] = None,
+    spot_instance_type: typing.Optional[SpotInstanceType] = None,
+    valid_until: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__59b1dd8d3301a15069c69deac346d143286429af8f0aa09e38100294c49388c3(
+    *,
+    instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+    instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+    machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+    spot_options: typing.Optional[typing.Union[SpotOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    user_data: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData] = None,
+    vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
+    default_capacity_size: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0805845bdc6545defca9fbcf4d117953ddd60be3e05b25bb8c71ceb7fccd6444(
+    *,
+    instance_profile: typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile] = None,
+    instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+    machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+    spot_options: typing.Optional[typing.Union[SpotOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    user_data: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.UserData] = None,
+    vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
+    default_capacity_size: typing.Optional[jsii.Number] = None,
+    terminate_instances_with_expiration: typing.Optional[builtins.bool] = None,
+    valid_from: typing.Optional[builtins.str] = None,
+    valid_until: typing.Optional[builtins.str] = None,
+    vpc_subnet: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
